@@ -34,10 +34,10 @@ Rcpp::NumericVector esf_mst_sum_vector_s1(
   /* loop variables */
   int mm = par.size();
   int i, k, r, ncol, ocol;
-  Rcpp::NumericVector gamma0(m * rmax);
-  Rcpp::NumericMatrix gamma1(rmax, m);
+  Rcpp::NumericVector gamma0 = (m * rmax);
+  // Rcpp::NumericMatrix gamma1(rmax, m);
 
-  /* clear given gamma0 */
+  /* clear gamma */
   for (k = 0; k < m * rmax; k++) {
     if ((k % rmax) == 0) {
       gamma0[k] = 1.0;
@@ -47,14 +47,13 @@ Rcpp::NumericVector esf_mst_sum_vector_s1(
       gamma0[k] = 0.0;
     }
   }
-/* summation algorithm, zero order */
-for (i = 1; i < m; i++) { /* successively add items */
-/* calculate column indices once */
+
+for (i = 1; i < m; i++) { 
   ncol = i * rmax;
   ocol = (i-1) * rmax;
   for (r = 1; r < rcum[i]; r++) {
-    gamma0[r + ncol] = gamma0[r + ocol];   /* already score r with i-1 items or ... */
-    for (k = 0; (k < oj[i]) & (k <= r); k++) /* ..score r-k and now cat k (0 means 1). */
+    gamma0[r + ncol] = gamma0[r + ocol];   
+    for (k = 0; (k < oj[i]) & (k <= r); k++)
       gamma0[r + ncol] += gamma0[r - (k + 1) + ocol] * par[eps_position[i]+k];
     }
   }
